@@ -38,6 +38,8 @@ class Settings { /* {{{ */
 	var $_rootFolderID = 1;
 	// If you want anybody to login as guest, set the following line to true
 	var $_enableGuestLogin = false;
+	// Allow users to reset their password
+	var $_enablePasswordForgotten = false;
 	// Restricted access: only allow users to log in if they have an entry in
 	// the local database (irrespective of successful authentication with LDAP).
 	var $_restricted = true;
@@ -275,6 +277,7 @@ class Settings { /* {{{ */
 		$node = $xml->xpath('/configuration/system/authentication');
 		$tab = $node[0]->attributes();
 		$this->_enableGuestLogin = Settings::boolVal($tab["enableGuestLogin"]);
+		$this->_enablePasswordForgotten = Settings::boolVal($tab["enablePasswordForgotten"]);
 		$this->_restricted = Settings::boolVal($tab["restricted"]);
 		$this->_enableUserImage = Settings::boolVal($tab["enableUserImage"]);
 		$this->_disableSelfEdit = Settings::boolVal($tab["disableSelfEdit"]);
@@ -484,6 +487,7 @@ class Settings { /* {{{ */
     // XML Path: /configuration/system/authentication
     $node = $this->getXMLNode($xml, '/configuration/system', 'authentication');
     $this->setXMLAttributValue($node, "enableGuestLogin", $this->_enableGuestLogin);
+    $this->setXMLAttributValue($node, "enablePasswordForgotten", $this->_enablePasswordForgotten);
     $this->setXMLAttributValue($node, "restricted", $this->_restricted);
     $this->setXMLAttributValue($node, "enableUserImage", $this->_enableUserImage);
     $this->setXMLAttributValue($node, "disableSelfEdit", $this->_disableSelfEdit);
@@ -590,43 +594,53 @@ class Settings { /* {{{ */
 	function searchConfigFilePath() { /* {{{ */
 		$configFilePath = null;
 
+		if($configDir = $this->getConfigDir()) {
+			if (file_exists($configDir."/settings.xml"))
+				return $configDir."/settings.xml";
+		}
+/*
 		// Search config file
 		$_tmp = dirname($_SERVER['SCRIPT_FILENAME']);
-		if(is_link($_tmp))
-		{
+		if(is_link($_tmp)) {
 			$_arr = preg_split('/\//', $_tmp);
 			array_pop($_arr);
 
 			$configFilePath = implode('/', $_arr)."/conf/settings.xml";
-		}
-		else
-		{
+		} else {
 			if (file_exists("../conf/settings.xml"))
 				$configFilePath = "../conf/settings.xml";
 			else if (file_exists("conf/settings.xml"))
 				$configFilePath = "conf/settings.xml";
-			else
-			{
-//				echo "Configuration file not found <br>";
-//				echo "Please create conf/settings.xml file. You can use installation procedure or 'conf/settings.xml.template' file to help you";
-//				exit;
-			}
 		}
-
+*/
 		return $configFilePath;
 	} /* }}} */
 
 	/**
 	 * Returns absolute path for configuration files respecting links
 	 *
+	 * This function checks three directories for a configuration directory
+	 * 1. The directory where the current script is located adding '/conf'
+	 * 2. The parent directory of the current script adding '/conf'
+	 * 3. The directory /etc/letodms
 	 * @return NULL|string config directory
 	 */
 	function getConfigDir() { /* {{{ */
 		$_tmp = dirname($_SERVER['SCRIPT_FILENAME']);
 		$_arr = preg_split('/\//', $_tmp);
-		array_pop($_arr);
+		$configDir = null;
+		if(file_exists(implode('/', $_arr)."/conf/"))
+			$configDir = implode('/', $_arr)."/conf/";
+		else {
+			array_pop($_arr);
+			if(file_exists(implode('/', $_arr)."/conf/")) {
+				$configDir = implode('/', $_arr)."/conf/";
+			} else {
+				if(file_exists('/etc/letodms'))
+					$configDir = '/etc/letodms';
+			}
+		}
 
-		$configDir = implode('/', $_arr)."/conf/";
 		return $configDir;
 	} /* }}} */
 
@@ -758,20 +772,20 @@ class Settings { /* {{{ */
 			$errorMsgPerms = null;
 
 			// perms
-			if (!mkdir($this->_contentDir.'/_CHECK_TEST_')) {
+			if (!@mkdir($this->_contentDir.'/_CHECK_TEST_')) {
 				$errorMsgPerms .= "Create folder - ";
-			}
+			} else {
+				if (is_bool(file_put_contents($this->_contentDir.'/_CHECK_TEST_/_CHECK_TEST_', ""))) {
+					$errorMsgPerms .= "Create file - ";
+				} else {
+					if (!unlink ($this->_contentDir.'/_CHECK_TEST_/_CHECK_TEST_')) {
+						$errorMsgPerms .= "Delete file - ";
+					}
+				}
 
-			if (is_bool(file_put_contents($this->_contentDir.'/_CHECK_TEST_/_CHECK_TEST_', ""))) {
-				$errorMsgPerms .= "Create file - ";
-			}
-
-			if (!unlink ($this->_contentDir.'/_CHECK_TEST_/_CHECK_TEST_')) {
-				$errorMsgPerms .= "Delete file - ";
-			}
-
-			if (!rmdir($this->_contentDir.'/_CHECK_TEST_')) {
-				$errorMsgPerms .= "Delete folder";
+				if (!rmdir($this->_contentDir.'/_CHECK_TEST_')) {
+					$errorMsgPerms .= "Delete folder";
+				}
 			}
 
 			if (!is_null($errorMsgPerms)) {
@@ -881,6 +895,7 @@ class Settings { /* {{{ */
 									"systemerror" => $connTmp->ErrorMsg()
 									);
 							} else {
+							/*
 								$dms = new LetoDMS_Core_DMS($db, $this->_contentDir.$this->_contentOffsetDir);
 
 								if(!$dms->checkVersion()) {
@@ -891,6 +906,7 @@ class Settings { /* {{{ */
 										"suggestion" => 'updateDatabase'
 										);
 								}
+							*/
 							}
 						}
 					}
