@@ -116,22 +116,32 @@ class UI {
 	function htmlStartPage($title="", $bodyClass="") { /* {{{ */
 		global $theme, $settings;
 
-		echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"\n".
-			"\"http://www.w3.org/TR/html4/strict.dtd\">\n";
-		echo "<html>\n<head>\n";
-		echo "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n";
-		echo "<link rel=\"STYLESHEET\" type=\"text/css\" href=\"../styles/".$theme."/style.css\"/>\n";
-		echo "<link rel=\"STYLESHEET\" type=\"text/css\" href=\"../styles/print.css\" media=\"print\"/>\n";
-		echo "<link rel='shortcut icon' href='../styles/".$theme."/favicon.ico' type='image/x-icon'/>\n";
-		echo "<script type='text/javascript' src='../js/jquery.min.js'></script>\n";
-		echo "<title>".(strlen($settings->_siteName)>0 ? $settings->_siteName : "LetoDMS").(strlen($title)>0 ? ": " : "").$title."</title>\n";
-		echo "</head>\n";
-		echo "<body".(strlen($bodyClass)>0 ? " class=\"".$bodyClass."\"" : "").">\n";
+		if(file_exists("../themes/".$theme."/HTMLHead.html")) {
+			include("../themes/".$theme."/HTMLHead.html");
+		} else {
+			echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"\n".
+				"\"http://www.w3.org/TR/html4/strict.dtd\">\n";
+			echo "<html>\n<head>\n";
+			echo "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n";
+			echo "<link rel=\"STYLESHEET\" type=\"text/css\" href=\"../styles/".$theme."/style.css\"/>\n";
+			echo "<link rel=\"STYLESHEET\" type=\"text/css\" href=\"../styles/print.css\" media=\"print\"/>\n";
+			echo "<link rel='shortcut icon' href='../styles/".$theme."/favicon.ico' type='image/x-icon'/>\n";
+			echo "<script type='text/javascript' src='../js/jquery.min.js'></script>\n";
+			echo "<title>".(strlen($settings->_siteName)>0 ? $settings->_siteName : "LetoDMS").(strlen($title)>0 ? ": " : "").htmlspecialchars($title)."</title>\n";
+			echo "</head>\n";
+			echo "<body".(strlen($bodyClass)>0 ? " class=\"".$bodyClass."\"" : "").">\n";
+		}
 	} /* }}} */
 
 	function htmlEndPage() { /* {{{ */
+		global $theme;
+
 		UI::footNote();
-		echo "</body>\n</html>\n";
+		if(file_exists("../themes/".$theme."/HTMLFoot.html")) {
+			include("../themes/".$theme."/HTMLFoot.html");
+		} else {
+			echo "</body>\n</html>\n";
+		}
 	} /* }}} */
 
 	function footNote() { /* {{{ */
@@ -196,7 +206,7 @@ class UI {
 			(strlen($settings->_siteName)>0 ? $settings->_siteName : "LetoDMS").
 			"</div>\n";
 		echo "<span class=\"absSpacerNorm\"></span>\n";
-		echo "<div id=\"signatory\">".getMLText("signed_in_as")." ".$user->getFullName().
+		echo "<div id=\"signatory\">".getMLText("signed_in_as")." ".htmlspecialchars($user->getFullName()).
 			" (<a href=\"../op/op.Logout.php\">".getMLText("sign_out")."</a>).</div>\n";
 		echo "<div style=\"clear: both; height: 0px; font-size:0;\">&nbsp;</div>\n".
 			"</div>\n";
@@ -418,7 +428,6 @@ class UI {
 	} /* }}} */
 
 	function contentContainer($content) { /* {{{ */
-
 		echo "<div class=\"contentContainer\">\n";
 		echo "<div class=\"content\">\n";
 		echo "<div class=\"content-l\"><div class=\"content-r\"><div class=\"content-br\"><div class=\"content-bl\">\n";
@@ -441,15 +450,18 @@ class UI {
 		return;
 	} /* }}} */
 
-	function contentHeading($heading) { /* {{{ */
+	function contentHeading($heading, $noescape=false) { /* {{{ */
 
-		echo "<div class=\"contentHeading\">".$heading."</div>\n";
+		if($noescape)
+			echo "<div class=\"contentHeading\">".$heading."</div>\n";
+		else
+			echo "<div class=\"contentHeading\">".htmlspecialchars($heading)."</div>\n";
 		return;
 	} /* }}} */
 
 	function contentSubHeading($heading, $first=false) { /* {{{ */
 
-		echo "<div class=\"contentSubHeading\"".($first ? " id=\"first\"" : "").">".$heading."</div>\n";
+		echo "<div class=\"contentSubHeading\"".($first ? " id=\"first\"" : "").">".htmlspecialchars($heading)."</div>\n";
 		return;
 	} /* }}} */
 
@@ -523,7 +535,7 @@ class UI {
 				continue;
 			}
 			$index = ($objArr[$i]->getSequence() + $objArr[$i+1]->getSequence()) / 2;
-			print "  <option value=\"".$index."\">" . getMLText("seq_after", array("prevname" => $objArr[$i]->getName() ) );
+			print "  <option value=\"".$index."\">" . getMLText("seq_after", array("prevname" => htmlspecialchars($objArr[$i]->getName())));
 		}
 		print "</select>";
 	} /* }}} */
@@ -554,7 +566,7 @@ class UI {
 		</script>
 		<?php
 		print "<input type=\"Hidden\" name=\"targetid".$formName."\" value=\"". (($default) ? $default->getID() : "") ."\">";
-		print "<input disabled name=\"targetname".$formName."\" value=\"". (($default) ? $default->getName() : "") ."\">";
+		print "<input disabled name=\"targetname".$formName."\" value=\"". (($default) ? htmlspecialchars($default->getName()) : "") ."\">";
 		print "&nbsp;&nbsp;<input type=\"Button\" value=\"".getMLText("folder")."...\" onclick=\"chooseFolder".$formName."();\">";
 	} /* }}} */
 
@@ -564,20 +576,25 @@ class UI {
 		<script language="JavaScript">
 		var openDlg;
 		function chooseCategory<?php print $formName ?>() {
-			var current = document.<?= $formName ?>.categoryid<?= $formName ?>;
+			var current = document.<?php echo $formName ?>.categoryid<?php echo $formName ?>;
 			openDlg = open("out.CategoryChooser.php?form=<?php echo $formName?>&cats="+current.value, "openDlg", "width=480,height=480,scrollbars=yes,resizable=yes,status=yes");
 		}
+		function clearCategory<?php print $formName ?>() {
+			document.<?php echo $formName ?>.categoryid<?php echo $formName ?>.value = '';
+			document.<?php echo $formName ?>.categoryname<?php echo $formName ?>.value = '';
+		}
 		</script>
 <?php
 		$ids = $names = array();
 		if($categories) {
 			foreach($categories as $cat) {
 				$ids[] = $cat->getId();
-				$names[] = $cat->getName();
+				$names[] = htmlspecialchars($cat->getName());
 			}
 		}
 		print "<input type=\"hidden\" name=\"categoryid".$formName."\" value=\"".implode(',', $ids)."\">";
 		print "<input disabled name=\"categoryname".$formName."\" value=\"".implode(' ', $names)."\">";
+		print "&nbsp;&nbsp;<a href=\"javascript:clearCategory".$formName."();\"><img src=\"images/del.gif\" width=\"15\" height=\"15\" border=\"0\" align=\"absmiddle\" alt=\"\"></a>";
 		print "&nbsp;&nbsp;<input type=\"Button\" value=\"".getMLText("category")."...\" onclick=\"chooseCategory".$formName."();\">";
 	} /* }}} */
 
@@ -603,7 +620,7 @@ class UI {
 		UI::globalNavigation();
 
 		print "<div class=\"error\">";
-		print $error;
+		print htmlspecialchars($error);
 		print "</div>";
 		
 		UI::htmlEndPage();
@@ -676,18 +693,18 @@ class UI {
 			if ($folderID != $currentFolderID){
 			
 				if ($navigation) print "<a href=\"../out/out.ViewFolder.php?folderid=" . $folderID . "&showtree=1\">";
-				else print "<a class=\"foldertree_selectable\" href=\"javascript:folderSelected(" . $folderID . ", '" . sanitizeString($folder->getName()) . "')\">";
+				else print "<a class=\"foldertree_selectable\" href=\"javascript:folderSelected(" . $folderID . ", '" . str_replace("'", "\\'", $folder->getName()) . "')\">";
 
 			}else print "<span class=\"selectedfoldertree\">";
 			
-			if ($is_open) print "<img src=\"".UI::getImgPath("folder_opened.gif")."\" border=0 name=\"treeimg".$folderID."\">".$folder->getName();
-			else print "<img src=\"".UI::getImgPath("folder_closed.gif")."\" border=0 name=\"treeimg".$folderID."\">".$folder->getName();
+			if ($is_open) print "<img src=\"".UI::getImgPath("folder_opened.gif")."\" border=0 name=\"treeimg".$folderID."\">".htmlspecialchars($folder->getName());
+			else print "<img src=\"".UI::getImgPath("folder_closed.gif")."\" border=0 name=\"treeimg".$folderID."\">".htmlspecialchars($folder->getName());
 
 			if ($folderID != $currentFolderID) print "</a>\n";
 			else print "</span>";
 
 		}
-		else print "<img src=\"".UI::getImgPath("folder_closed.gif")."\" width=18 height=18 border=0>".$folder->getName()."\n";
+		else print "<img src=\"".UI::getImgPath("folder_closed.gif")."\" width=18 height=18 border=0>".htmlspecialchars($folder->getName())."\n";
 
 		if ($is_open) print "<ul style='list-style-type: none;' id=\"tree".$folderID."\" >\n";
 		else print "<ul style='list-style-type: none; display: none;' id=\"tree".$folderID."\" >\n";
@@ -733,7 +750,7 @@ class UI {
 
 			print "<td id='tree-open'>";
 
-			UI::contentHeading("<a href=\"../out/out.ViewFolder.php?folderid=". $folderid."&showtree=0\"><img src=\"".UI::getImgPath("m.png")."\" border=0></a>");
+			UI::contentHeading("<a href=\"../out/out.ViewFolder.php?folderid=". $folderid."&showtree=0\"><img src=\"".UI::getImgPath("m.png")."\" border=0></a>", true);
 			UI::contentContainerStart();
 			UI::printFoldersTree(M_READ, -1, $settings->_rootFolderID, $folderid, true);
 			UI::contentContainerEnd();
@@ -742,7 +759,7 @@ class UI {
 		
 			print "<td id='tree-closed'>";		
 		
-			UI::contentHeading("<a href=\"../out/out.ViewFolder.php?folderid=". $folderid."&showtree=1\"><img src=\"".UI::getImgPath("p.png")."\" border=0></a>");
+			UI::contentHeading("<a href=\"../out/out.ViewFolder.php?folderid=". $folderid."&showtree=1\"><img src=\"".UI::getImgPath("p.png")."\" border=0></a>", true);
 			UI::contentContainerStart();
 			UI::contentContainerEnd();
 		}
@@ -767,16 +784,16 @@ archive="jl_core_z.jar"
 width="715"
 height="400"
 mayscript>
-  <param name="uc_uploadUrl" value="<?= $uploadurl ?>"/>
+  <param name="uc_uploadUrl" value="<?php echo $uploadurl ?>"/>
   <param name="ac_fireAppletInitialized" value="true"/>
   <param name="ac_fireUploaderSelectionChanged" value="true"/>
   <param name="ac_fireUploaderFileStatusChanged" value="true"/>
   <param name="ac_fireUploaderFileAdded" value="true"/>
-  <param name="uc_partitionLength" value="<?= $settings->_partitionSize ?>"/>
+  <param name="uc_partitionLength" value="<?php echo $settings->_partitionSize ?>"/>
 <?php
 	if($maxfiles) {
 ?>
-  <param name="uc_maxFiles" value="<?= $maxfiles ?>"/>
+  <param name="uc_maxFiles" value="<?php echo $maxfiles ?>"/>
 <?php
 	}
 ?>
@@ -796,7 +813,7 @@ mayscript>
 <?php
 	foreach($attributes as $name=>$value) {
 ?>
-        attr = attrSet.createStringAttribute( '<?= $name ?>', '<?= $value ?>' );
+        attr = attrSet.createStringAttribute( '<?php echo $name ?>', '<?php echo $value ?>' );
         attr.setSendToServer(true);
 <?php
 	}
@@ -853,7 +870,7 @@ mayscript>
 	if(!$fields || (isset($fields['name']) && $fields['name'])) {
 ?>
         content += "<tr class='dataRow'>";
-        content += "<td class='dataField'><?= getMLText('name') ?></td>";
+        content += "<td class='dataField'><?php echo getMLText('name') ?></td>";
 				if(attr = attrSet.getAttributeByName('name'))
 					value = attr.getStringValue();
 				else
@@ -870,7 +887,7 @@ mayscript>
 	if(!$fields || (isset($fields['comment']) && $fields['comment'])) {
 ?>
         content += "<tr class='dataRow'>";
-        content += "<td class='dataField'><?= getMLText('comment') ?></td>";
+        content += "<td class='dataField'><?php echo getMLText('comment') ?></td>";
 				if(attr = attrSet.getAttributeByName('comment'))
 					value = attr.getStringValue();
 				else
@@ -887,7 +904,7 @@ mayscript>
 	if(!$fields || (isset($fields['reqversion']) && $fields['reqversion'])) {
 ?>
         content += "<tr class='dataRow'>";
-        content += "<td class='dataField'><?= getMLText('version') ?></td>";
+        content += "<td class='dataField'><?php echo getMLText('version') ?></td>";
 				if(attr = attrSet.getAttributeByName('reqversion'))
 					value = attr.getStringValue();
 				else
@@ -904,7 +921,7 @@ mayscript>
 	if(!$fields || (isset($fields['version_comment']) && $fields['version_comment'])) {
 ?>
         content += "<tr class='dataRow'>";
-        content += "<td class='dataField'><?= getMLText('comment_for_current_version') ?></td>";
+        content += "<td class='dataField'><?php echo getMLText('comment_for_current_version') ?></td>";
 				if(attr = attrSet.getAttributeByName('version_comment'))
 					value = attr.getStringValue();
 				else
@@ -921,14 +938,14 @@ mayscript>
 	if(!$fields || (isset($fields['keywords']) && $fields['keywords'])) {
 ?>
         content += "<tr class='dataRow'>";
-        content += "<td class='dataField'><?= getMLText('keywords') ?></td>";
+        content += "<td class='dataField'><?php echo getMLText('keywords') ?></td>";
 				if(attr = attrSet.getAttributeByName('keywords'))
 					value = attr.getStringValue();
 				else
 					value = '';
 				if(edit) {
 					value = "<textarea id='keywords" + index + "' name='keywords' cols='40' rows='2'>" + value + "</textarea>";
-					value += "<br /><a href='javascript:chooseKeywords(\"form" + index + ".keywords" + index +"\");'><?= getMLText("use_default_keywords");?></a>";
+					value += "<br /><a href='javascript:chooseKeywords(\"form" + index + ".keywords" + index +"\");'><?php echo getMLText("use_default_keywords");?></a>";
 				}
         content += "<td class='dataText'>" + value + "</td>";
         content += "</tr>";
@@ -940,7 +957,7 @@ mayscript>
 	if(!$fields || (isset($fields['categories']) && $fields['categories'])) {
 ?>
 				content += "<tr class='dataRow'>";
-				content += "<td class='dataField'><?= getMLText('categories') ?></td>";
+				content += "<td class='dataField'><?php echo getMLText('categories') ?></td>";
 				if(attr = attrSet.getAttributeByName('categoryids'))
 					value = attr.getStringValue();
 				else
@@ -952,7 +969,7 @@ mayscript>
 				if(edit) {
 					value = "<input type='hidden' id='categoryidform" + index + "' name='categoryids' value='" + value + "' />";
 					value += "<input disabled id='categorynameform" + index + "' name='categorynames' value='" + value2 + "' />";
-					value += "<br /><a href='javascript:chooseCategory(\"form" + index + "\", \"\");'><?= getMLText("use_default_categories");?></a>";
+					value += "<br /><a href='javascript:chooseCategory(\"form" + index + "\", \"\");'><?php echo getMLText("use_default_categories");?></a>";
 				} else {
 					value = value2;
 				}
