@@ -55,7 +55,6 @@ function ShowHide(strId)
 }
 </script>
 
-
   <form action="../op/op.Settings.php" method="post" enctype="multipart/form-data" name="form0" >
   <input type="Hidden" name="action" value="saveSettings" />
 <?php
@@ -266,6 +265,10 @@ if(!is_writeable($settings->_configFilePath)) {
         <td><?php printMLText("settings_disableSelfEdit");?>:</td>
         <td><input name="disableSelfEdit" type="checkbox" <?php if ($settings->_disableSelfEdit) echo "checked" ?> /></td>
       </tr>
+      <tr title="<?php printMLText("settings_enablePasswordForgotten_desc");?>">
+        <td><?php printMLText("settings_enablePasswordForgotten");?>:</td>
+        <td><input name="enablePasswordForgotten" type="checkbox" <?php if ($settings->_enablePasswordForgotten) echo "checked" ?> /></td>
+      </tr>
 
       <!-- TODO Connectors -->
 
