@@ -48,7 +48,7 @@ if (!is_object($document)) {
 }
 
 $folder = $document->getFolder();
-$docPathHTML = getFolderPathHTML($folder, true). " / ".$document->getName();
+$docPathHTML = getFolderPathHTML($folder, true). " / ".htmlspecialchars($document->getName());
 
 if ($document->getAccessMode($user) < M_READ) {
 	UI::exitError(getMLText("document_title", array("documentname" => $document->getName())),getMLText("access_denied"));
@@ -80,7 +80,7 @@ if ($document->isLocked()) {
 	$lockingUser = $document->getLockingUser();
 ?>
 <tr>
-	<td class="warning" colspan=2><?php printMLText("lock_message", array("email" => $lockingUser->getEmail(), "username" => $lockingUser->getFullName()));?></td>
+	<td class="warning" colspan=2><?php printMLText("lock_message", array("email" => $lockingUser->getEmail(), "username" => htmlspecialchars($lockingUser->getFullName())));?></td>
 </tr>
 <?php
 }
@@ -96,7 +96,7 @@ print "<a class=\"infos\" href=\"mailto:".$owner->getEmail()."\">".$owner->getFu
 </tr>
 <tr>
 <td><?php printMLText("comment");?>:</td>
-<td><?php print $document->getComment();?></td>
+<td><?php print htmlspecialchars($document->getComment());?></td>
 </tr>
 <tr>
 <td><?php printMLText("creation_date");?>:</td>
@@ -104,7 +104,7 @@ print "<a class=\"infos\" href=\"mailto:".$owner->getEmail()."\">".$owner->getFu
 </tr>
 <tr>
 <td><?php printMLText("keywords");?>:</td>
-<td><?php print $document->getKeywords();?></td>
+<td><?php print htmlspecialchars($document->getKeywords());?></td>
 </tr>
 <tr>
 <td><?php printMLText("categories");?>:</td>
@@ -113,7 +113,7 @@ print "<a class=\"infos\" href=\"mailto:".$owner->getEmail()."\">".$owner->getFu
 	$cats = $document->getCategories();
 	$ct = array();
 	foreach($cats as $cat)
-		$ct[] = $cat->getName();
+		$ct[] = htmlspecialchars($cat->getName());
 	echo implode(', ', $ct);
 ?>
 </td>
@@ -137,10 +137,10 @@ print "<tr>\n";
 print "<td><ul class=\"actions\">";
 
 if ($file_exists){
-	print "<li><a href=\"../op/op.Download.php?documentid=".$documentid."&version=".$latestContent->getVersion()."\"><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($latestContent->getFileType())."\" title=\"".$latestContent->getMimeType()."\">".getMLText("download")."</a></li>";
+	print "<li><a href=\"../op/op.Download.php?documentid=".$documentid."&version=".$latestContent->getVersion()."\"><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($latestContent->getFileType())."\" title=\"".htmlspecialchars($latestContent->getMimeType())."\">".getMLText("download")."</a></li>";
 	if ($settings->_viewOnlineFileTypes && in_array(strtolower($latestContent->getFileType()), $settings->_viewOnlineFileTypes))
 		print "<li><a target=\"_blank\" href=\"../op/op.ViewOnline.php?documentid=".$documentid."&version=". $latestContent->getVersion()."\"><img src=\"images/view.gif\" class=\"mimeicon\">" . getMLText("view_online") . "</a></li>";
-}else print "<li><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($latestContent->getFileType())."\" title=\"".$latestContent->getMimeType()."\"></li>";
+}else print "<li><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($latestContent->getFileType())."\" title=\"".htmlspecialchars($latestContent->getMimeType())."\"></li>";
 
 print "</ul></td>\n";
 print "<td>".$latestContent->getVersion()."</td>\n";
@@ -149,15 +149,15 @@ print "<td><ul class=\"documentDetail\">\n";
 print "<li>".$latestContent->getOriginalFileName() ."</li>\n";
 
 if ($file_exists)
-	print "<li>". formatted_size(filesize($dms->contentDir . $latestContent->getPath())) ." ".$latestContent->getMimeType()."</li>";
+	print "<li>". formatted_size(filesize($dms->contentDir . $latestContent->getPath())) ." ".htmlspecialchars($latestContent->getMimeType())."</li>";
 else print "<li><span class=\"warning\">".getMLText("document_deleted")."</span></li>";
 
 $updatingUser = $latestContent->getUser();
-print "<li>".getMLText("uploaded_by")." <a href=\"mailto:".$updatingUser->getEmail()."\">".$updatingUser->getFullName()."</a></li>";
+print "<li>".getMLText("uploaded_by")." <a href=\"mailto:".$updatingUser->getEmail()."\">".htmlspecialchars($updatingUser->getFullName())."</a></li>";
 print "<li>".getLongReadableDate($latestContent->getDate())."</li>";
 
 print "</ul>\n";
-print "<td>".$latestContent->getComment()."</td>";
+print "<td>".htmlspecialchars($latestContent->getComment())."</td>";
 
 print "<td width='10%'>".getOverallStatusText($status["status"]);
 if ( $status["status"]==S_DRAFT_REV || $status["status"]==S_DRAFT_APP || $status["status"]==S_EXPIRED ){
@@ -192,46 +192,6 @@ print "</ul>";
 echo "</td>";
 print "</tr></tbody>\n</table>\n";
 
-//
-// retrieve if the user is a reviewer or approver for this document.
-//
-$userRStat = $user->getReviewStatus($documentid, $latestContent->getVersion());
-$userAStat = $user->getApprovalStatus($documentid, $latestContent->getVersion());
-$is_reviewer = false;
-$is_approver = false;
-
-if (!is_bool($userRStat)) {
-	if (count($userRStat["indstatus"])>0) {
-		if ($userRStat["indstatus"][0]["status"]==0) {
-			$is_reviewer = true;
-		}
-	}
-	else {
-		foreach ($userRStat["grpstatus"] as $grpstatus) {
-			if ($grpstatus["status"]==0) {
-				$is_reviewer = true;
-				break;
-			}
-		}
-	}
-}
-if (!is_bool($userAStat)) {
-	if (count($userAStat["indstatus"])>0) {
-		if ($userAStat["indstatus"][0]["status"]==0) {
-			$is_approver = true;
-		}
-	}
-	else {
-		foreach ($userAStat["grpstatus"] as $grpstatus) {
-			if ($grpstatus["status"]==0) {
-				$is_approver = true;
-				break;
-			}
-		}
-	}
-}
-
-
 print "<table class=\"folderView\">\n";
 
 if (is_array($reviewStatus) && count($reviewStatus)>0) {
@@ -250,6 +210,7 @@ if (is_array($reviewStatus) && count($reviewStatus)>0) {
 
 	foreach ($reviewStatus as $r) {
 		$required = null;
+		$is_reviewer = false;
 		switch ($r["type"]) {
 			case 0: // Reviewer is an individual.
 				$required = $dms->getUser($r["required"]);
@@ -257,8 +218,10 @@ if (is_array($reviewStatus) && count($reviewStatus)>0) {
 					$reqName = getMLText("unknown_user")." '".$r["required"]."'";
 				}
 				else {
-					$reqName = $required->getFullName();
+					$reqName = htmlspecialchars($required->getFullName());
 				}
+				if($r["required"] == $user->getId())
+					$is_reviewer = true;
 				break;
 			case 1: // Reviewer is a group.
 				$required = $dms->getGroup($r["required"]);
@@ -266,23 +229,25 @@ if (is_array($reviewStatus) && count($reviewStatus)>0) {
 					$reqName = getMLText("unknown_group")." '".$r["required"]."'";
 				}
 				else {
-					$reqName = "<i>".$required->getName()."</i>";
+					$reqName = "<i>".htmlspecialchars($required->getName())."</i>";
 				}
+				if($required->isMember($user))
+					$is_reviewer = true;
 				break;
 		}
 		print "<tr>\n";
 		print "<td>".$reqName."</td>\n";
 		print "<td><ul class=\"documentDetail\"><li>".$r["date"]."</li>";
 		$updateUser = $dms->getUser($r["userID"]);
-		print "<li>".(is_object($updateUser) ? $updateUser->getFullName() : "unknown user id '".$r["userID"]."'")."</li></ul></td>";
-		print "<td>".$r["comment"]."</td>\n";
+		print "<li>".(is_object($updateUser) ? htmlspecialchars($updateUser->getFullName()) : "unknown user id '".$r["userID"]."'")."</li></ul></td>";
+		print "<td>".htmlspecialchars($r["comment"])."</td>\n";
 		print "<td>".getReviewStatusText($r["status"])."</td>\n";
 		print "<td><ul class=\"actions\">";
 		
-		if (($required==$user) && $is_reviewer && $status["status"]==S_DRAFT_REV) {
-			print "<li><a href=\"../out/out.ReviewDocument.php?documentid=".$documentid."&version=".$latestContent->getVersion()."\">".getMLText("submit_review")."</a></li>";
+		if ($is_reviewer && $status["status"]==S_DRAFT_REV) {
+			print "<li><a href=\"../out/out.ReviewDocument.php?documentid=".$documentid."&version=".$latestContent->getVersion()."&reviewid=".$r['reviewID']."\">".getMLText("submit_review")."</a></li>";
 		}else if (($updateUser==$user)&&(($r["status"]==1)||($r["status"]==-1))&&(!$document->hasExpired())){
-			print "<li><a href=\"../out/out.ReviewDocument.php?documentid=".$documentid."&version=".$latestContent->getVersion()."\">".getMLText("edit")."</a></li>";
+			print "<li><a href=\"../out/out.ReviewDocument.php?documentid=".$documentid."&version=".$latestContent->getVersion()."&reviewid=".$r['reviewID']."\">".getMLText("edit")."</a></li>";
 		}
 		
 		print "</ul></td>\n";	
@@ -306,6 +271,7 @@ if (is_array($approvalStatus) && count($approvalStatus)>0) {
 
 	foreach ($approvalStatus as $a) {
 		$required = null;
+		$is_approver = false;
 		switch ($a["type"]) {
 			case 0: // Approver is an individual.
 				$required = $dms->getUser($a["required"]);
@@ -313,8 +279,10 @@ if (is_array($approvalStatus) && count($approvalStatus)>0) {
 					$reqName = getMLText("unknown_user")." '".$r["required"]."'";
 				}
 				else {
-					$reqName = $required->getFullName();
+					$reqName = htmlspecialchars($required->getFullName());
 				}
+				if($a["required"] == $user->getId())
+					$is_approver = true;
 				break;
 			case 1: // Approver is a group.
 				$required = $dms->getGroup($a["required"]);
@@ -322,23 +290,25 @@ if (is_array($approvalStatus) && count($approvalStatus)>0) {
 					$reqName = getMLText("unknown_group")." '".$r["required"]."'";
 				}
 				else {
-					$reqName = "<i>".$required->getName()."</i>";
+					$reqName = "<i>".htmlspecialchars($required->getName())."</i>";
 				}
+				if($required->isMember($user))
+					$is_approver = true;
 				break;
 		}
 		print "<tr>\n";
 		print "<td>".$reqName."</td>\n";
 		print "<td><ul class=\"documentDetail\"><li>".$a["date"]."</li>";
 		$updateUser = $dms->getUser($a["userID"]);
-		print "<li>".(is_object($updateUser) ? $updateUser->getFullName() : "unknown user id '".$a["userID"]."'")."</li></ul></td>";	
-		print "<td>".$a["comment"]."</td>\n";
+		print "<li>".(is_object($updateUser) ? htmlspecialchars($updateUser->getFullName()) : "unknown user id '".$a["userID"]."'")."</li></ul></td>";	
+		print "<td>".htmlspecialchars($a["comment"])."</td>\n";
 		print "<td>".getApprovalStatusText($a["status"])."</td>\n";
 		print "<td><ul class=\"actions\">";
-		
+	
 		if ($is_approver && $status["status"]==S_DRAFT_APP) {
-			print "<li><a href=\"../out/out.ApproveDocument.php?documentid=".$documentid."&version=".$latestContent->getVersion()."\">".getMLText("submit_approval")."</a></li>";
+			print "<li><a href=\"../out/out.ApproveDocument.php?documentid=".$documentid."&version=".$latestContent->getVersion()."&approveid=".$a['approveID']."\">".getMLText("submit_approval")."</a></li>";
 		}else if (($updateUser==$user)&&(($a["status"]==1)||($a["status"]==-1))&&(!$document->hasExpired())){
-			print "<li><a href=\"../out/out.ApproveDocument.php?documentid=".$documentid."&version=".$latestContent->getVersion()."\">".getMLText("edit")."</a></li>";
+			print "<li><a href=\"../out/out.ApproveDocument.php?documentid=".$documentid."&version=".$latestContent->getVersion()."&approveid=".$a['approveID']."\">".getMLText("edit")."</a></li>";
 		}
 		
 		print "</ul></td>\n";	
@@ -368,7 +338,6 @@ if (count($versions)>1) {
 	for ($i = count($versions)-2; $i >= 0; $i--) {
 		$version = $versions[$i];
 		$vstat = $version->getStatus();
-		$comment = $version->getComment();
 		
 		// verify if file exists
 		$file_exists=file_exists($dms->contentDir . $version->getPath());
@@ -376,22 +345,22 @@ if (count($versions)>1) {
 		print "<tr>\n";
 		print "<td><ul class=\"actions\">";
 		if ($file_exists){
-			print "<li><a href=\"../op/op.Download.php?documentid=".$documentid."&version=".$version->getVersion()."\"><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($version->getFileType())."\" title=\"".$version->getMimeType()."\">".getMLText("download")."</a>";
+			print "<li><a href=\"../op/op.Download.php?documentid=".$documentid."&version=".$version->getVersion()."\"><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($version->getFileType())."\" title=\"".htmlspecialchars($version->getMimeType())."\">".getMLText("download")."</a>";
 			if ($settings->_viewOnlineFileTypes && in_array(strtolower($latestContent->getFileType()), $settings->_viewOnlineFileTypes))
 				print "<li><a target=\"_blank\" href=\"../op/op.ViewOnline.php?documentid=".$documentid."&version=".$version->getVersion()."\"><img src=\"images/view.gif\" class=\"mimeicon\">" . getMLText("view_online") . "</a>";
-		}else print "<li><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($version->getFileType())."\" title=\"".$version->getMimeType()."\">";
+		}else print "<li><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($version->getFileType())."\" title=\"".htmlspecialchars($version->getMimeType())."\">";
 		
 		print "</ul></td>\n";
 		print "<td>".$version->getVersion()."</td>\n";
 		print "<td><ul class=\"documentDetail\">\n";
 		print "<li>".$version->getOriginalFileName()."</li>\n";
-		if ($file_exists) print "<li>". formatted_size(filesize($dms->contentDir . $version->getPath())) ." ".$version->getMimeType()."</li>";
+		if ($file_exists) print "<li>". formatted_size(filesize($dms->contentDir . $version->getPath())) ." ".htmlspecialchars($version->getMimeType())."</li>";
 		else print "<li><span class=\"warning\">".getMLText("document_deleted")."</span></li>";
 		$updatingUser = $version->getUser();
-		print "<li>".getMLText("uploaded_by")." <a href=\"mailto:".$updatingUser->getEmail()."\">".$updatingUser->getFullName()."</a></li>";
+		print "<li>".getMLText("uploaded_by")." <a href=\"mailto:".$updatingUser->getEmail()."\">".htmlspecialchars($updatingUser->getFullName())."</a></li>";
 		print "<li>".getLongReadableDate($version->getDate())."</li>";
 		print "</ul>\n";
-		print "<td>".$version->getComment()."</td>";
+		print "<td>".htmlspecialchars($version->getComment())."</td>";
 		print "<td>".getOverallStatusText($vstat["status"])."</td>";
 		print "<td>";
 		print "<ul class=\"actions\">";
@@ -432,20 +401,20 @@ if (count($files) > 0) {
 		print "<tr>";
 		print "<td><ul class=\"actions\">";
 		if ($file_exists)
-			print "<li><a href=\"../op/op.Download.php?documentid=".$documentid."&file=".$file->getID()."\"><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($file->getFileType())."\" title=\"".$file->getMimeType()."\">".$file->getName()."</a>";
-		else print "<li><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($file->getFileType())."\" title=\"".$file->getMimeType()."\">";
+			print "<li><a href=\"../op/op.Download.php?documentid=".$documentid."&file=".$file->getID()."\"><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($file->getFileType())."\" title=\"".htmlspecialchars($file->getMimeType())."\">".htmlspecialchars($file->getName())."</a>";
+		else print "<li><img class=\"mimeicon\" src=\"images/icons/".UI::getMimeIcon($file->getFileType())."\" title=\"".htmlspecialchars($file->getMimeType())."\">";
 		print "</ul></td>";
 		
 		print "<td><ul class=\"documentDetail\">\n";
 		print "<li>".$file->getOriginalFileName() ."</li>\n";
 		if ($file_exists)
-			print "<li>". filesize($dms->contentDir . $file->getPath()) ." bytes ".$file->getMimeType()."</li>";
-		else print "<li>".$file->getMimeType()." - <span class=\"warning\">".getMLText("document_deleted")."</span></li>";
+			print "<li>". filesize($dms->contentDir . $file->getPath()) ." bytes ".htmlspecialchars($file->getMimeType())."</li>";
+		else print "<li>".htmlspecialchars($file->getMimeType())." - <span class=\"warning\">".getMLText("document_deleted")."</span></li>";
 
-		print "<li>".getMLText("uploaded_by")." <a href=\"mailto:".$responsibleUser->getEmail()."\">".$responsibleUser->getFullName()."</a></li>";
+		print "<li>".getMLText("uploaded_by")." <a href=\"mailto:".$responsibleUser->getEmail()."\">".htmlspecialchars($responsibleUser->getFullName())."</a></li>";
 		print "<li>".getLongReadableDate($file->getDate())."</li>";
 
-		print "<td>".$file->getComment()."</td>";
+		print "<td>".htmlspecialchars($file->getComment())."</td>";
 	
 		print "<td><span class=\"actions\">";
 		if (($document->getAccessMode($user) == M_ALL)||($file->getUserID()==$user->getID()))
@@ -486,9 +455,9 @@ if (count($links) > 0) {
 		$targetDoc = $link->getTarget();
 
 		print "<tr>";
-		print "<td><a href=\"out.ViewDocument.php?documentid=".$targetDoc->getID()."\" class=\"linklist\">".$targetDoc->getName()."</a></td>";
-		print "<td>".$targetDoc->getComment()."</td>";
-		print "<td>".$responsibleUser->getFullName();
+		print "<td><a href=\"out.ViewDocument.php?documentid=".$targetDoc->getID()."\" class=\"linklist\">".htmlspecialchars($targetDoc->getName())."</a></td>";
+		print "<td>".htmlspecialchars($targetDoc->getComment())."</td>";
+		print "<td>".htmlspecialchars($responsibleUser->getFullName());
 		if (($user->getID() == $responsibleUser->getID()) || ($document->getAccessMode($user) == M_ALL ))
 			print "<br>".getMLText("document_link_public").":".(($link->isPublic()) ? getMLText("yes") : getMLText("no"));
 		print "</td>";
