@@ -1,7 +1,10 @@
 <?php
 
 require_once "HTTP/WebDAV/Server.php";
-require_once "LetoDMS/Core.php";
+if(!empty($settings->_coreDir))
+	require_once($settings->_coreDir.'/Core.php');
+else
+	require_once('LetoDMS/Core.php');
 
 /**
  * LetoDMS access using WebDAV
@@ -111,7 +114,7 @@ class HTTP_WebDAV_Server_LetoDMS extends HTTP_WebDAV_Server
 	function check_auth($type, $user, $pass) /* {{{ */
 	{
 		if($this->logger)
-			$this->logger->log('check_auth: user='.$user.'', PEAR_LOG_INFO);
+			$this->logger->log('check_auth: type='.$type.', user='.$user.'', PEAR_LOG_INFO);
 		$userobj = $this->dms->getUserByLogin($user);
 		if(!$userobj)
 			return false;
@@ -133,7 +136,7 @@ class HTTP_WebDAV_Server_LetoDMS extends HTTP_WebDAV_Server
 	 */
 	function reverseLookup($path) /* {{{ */
 	{
-		$path = urldecode($path);
+		$path = rawurldecode($path);
 		if($this->logger)
 			$this->logger->log('reverseLookup: path='.$path.'', PEAR_LOG_DEBUG);
 
@@ -227,6 +230,7 @@ class HTTP_WebDAV_Server_LetoDMS extends HTTP_WebDAV_Server
 		if (get_class($obj) == 'LetoDMS_Core_Folder' && !empty($options["depth"])) {
 
 			$subfolders = $obj->getSubFolders();
+			$subfolders = LetoDMS_Core_DMS::filterAccess($subfolders, $this->user, M_READ);
 			if ($subfolders) {
 				// ok, now get all its contents
 				foreach($subfolders as $subfolder) {
@@ -235,6 +239,7 @@ class HTTP_WebDAV_Server_LetoDMS extends HTTP_WebDAV_Server
 				// TODO recursion needed if "Depth: infinite"
 			}
 			$documents = $obj->getDocuments();
+			$documents = LetoDMS_Core_DMS::filterAccess($documents, $this->user, M_READ);
 			if ($documents) {
 				// ok, now get all its contents
 				foreach($documents as $document) {
@@ -272,12 +277,14 @@ class HTTP_WebDAV_Server_LetoDMS extends HTTP_WebDAV_Server
 			array_shift($patharr);
 			$path = '';
 			foreach($patharr as $pathseg)
-				$path .= '/'.rawurlencode($pathseg->getName());
+//				$path .= '/'.rawurlencode($pathseg->getName());
+				$path .= '/'.$pathseg->getName();
 			if(!$path) {
 				$path = '/';
 				$info["props"][] = $this->mkprop("isroot", "true");
 			}
-			$info["path"] = htmlspecialchars($path);
+//			$info["path"] = htmlspecialchars($path);
+			$info["path"] = $path;
 			$info["props"][] = $this->mkprop("displayname", $obj->getName());
 			$info["props"][] = $this->mkprop("resourcetype", "collection");
 			$info["props"][] = $this->mkprop("getcontenttype", "httpd/unix-directory");
@@ -291,8 +298,10 @@ class HTTP_WebDAV_Server_LetoDMS extends HTTP_WebDAV_Server
 			array_shift($patharr);
 			$path = '/';
 			foreach($patharr as $pathseg)
-				$path .= rawurlencode($pathseg->getName()).'/';
-			$info["path"] = htmlspecialchars($path.rawurlencode($obj->getName()));
+//				$path .= rawurlencode($pathseg->getName()).'/';
+				$path .= $pathseg->getName().'/';
+//			$info["path"] = htmlspecialchars($path.rawurlencode($obj->getName()));
+			$info["path"] = $path.$obj->getName();
 			$info["props"][] = $this->mkprop("displayname", $obj->getName());
 
 			$info["props"][] = $this->mkprop("resourcetype", "");
@@ -430,7 +439,7 @@ class HTTP_WebDAV_Server_LetoDMS extends HTTP_WebDAV_Server
 			printf($format, 
 				   number_format($filesize),
 				   strftime("%Y-%m-%d %H:%M:%S", $mtime), 
-				   "<a href='".$_SERVER['SCRIPT_NAME'].$fullpath."'>$name</a>");
+				   "<a href=\"".$_SERVER['SCRIPT_NAME'].htmlspecialchars($fullpath)."\">".htmlspecialchars($name, ENT_QUOTES)."</a>");
 		}
 
 		echo "</pre>";
